==> haskell-th-orphans-0.13.16-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-orphans
version:              0.13.16
visibility:           public
id:                   th-orphans-0.13.16-GJGpjmjzCIMG3DAQWUiMAF
key:                  th-orphans-0.13.16-GJGpjmjzCIMG3DAQWUiMAF
license:              BSD-3-Clause
copyright:            (c) Matt Morrow, Michael Sloan, Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Matt Morrow, Michael Sloan, Ryan Scott
stability:            experimental
synopsis:             Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.

category:             Template Haskell
abi:                  9ac9c48a36346fdf6c7ee7b5b0f1a705
exposed:              True
exposed-modules:      Language.Haskell.TH.Instances
hidden-modules:       Language.Haskell.TH.Instances.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-orphans-0.13.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-orphans-0.13.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-orphans-0.13.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-orphans
hs-libraries:         HSth-orphans-0.13.16-GJGpjmjzCIMG3DAQWUiMAF
depends:
    base-4.17.2.1 mtl-2.2.2 template-haskell-2.19.0.0
    th-compat-0.1.6-2dsduXetwx9FoOTSGmeukn
    th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl
    th-reify-many-0.1.10-2GGrrFheSeLJHA8AxJMH1Q

haddock-interfaces:   /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html:         /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-orphans-0.13.16-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-orphans
version:              0.13.16
visibility:           public
id:                   th-orphans-0.13.16-2tTTtSXV82lJaENcwrnU5L
key:                  th-orphans-0.13.16-2tTTtSXV82lJaENcwrnU5L
license:              BSD-3-Clause
copyright:            (c) Matt Morrow, Michael Sloan, Ryan Scott
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Matt Morrow, Michael Sloan, Ryan Scott
stability:            experimental
synopsis:             Orphan instances for TH datatypes
description:
    Orphan instances for TH datatypes.  In particular, instances
    for Ord and Lift, as well as a few missing Show / Eq.  These
    instances used to live in haskell-src-meta, and that'\''s where
    the version number started.

category:             Template Haskell
abi:                  94dc06b055f50aae3dbf7c2b85aa176a
exposed:              True
exposed-modules:      Language.Haskell.TH.Instances
hidden-modules:       Language.Haskell.TH.Instances.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-orphans-0.13.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-orphans-0.13.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-orphans-0.13.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-orphans
hs-libraries:         HSth-orphans-0.13.16-2tTTtSXV82lJaENcwrnU5L
depends:
    base-4.17.2.1 mtl-2.2.2 template-haskell-2.19.0.0
    th-compat-0.1.6-AykxSqsHYjoIEXB3w1XfuM
    th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl
    th-reify-many-0.1.10-5TAudCtsJPwofd8Bf5Rrw

haddock-interfaces:   /usr/share/doc/haskell-th-orphans/html/th-orphans.haddock
haddock-html:         /usr/share/doc/haskell-th-orphans/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
